@@ -10,7 +10,7 @@ import requests
 import json
 from .daylight import daylight
 import threading
-import time
+from time import time, sleep
 from decimal import Decimal
 from datetime import datetime, timedelta, timezone
 
@@ -39,7 +39,7 @@ class DataLogger(object):
         self.every = self._get_interval()
         self.interval_aggregated = self._get_interval_aggregated()
         # Wait at least a polling interval before submitting net data without solar aggegation
-        self.pasttime = time.time() + self.every
+        self.pasttime = time() + self.every
         tz = self.config.get("default", "timezone", fallback="Europe/Amsterdam")
         self.timezone = pytz.timezone(tz)
 
@@ -185,9 +185,12 @@ class DataLogger(object):
 
     def _init_attribute_dict(self):
         self.config.attributes = {}
-        asset_classes = list(["omnik", "omnik_dsmr", "dsmr", "dsmr_gas"])
+        asset_classes = list(
+            ["omnik", "omnik_attributes", "omnik_dsmr", "dsmr", "dsmr_gas"]
+        )
         self.config.attributes["asset"] = {
             "omnik": list(["inverter", "plant_id", "last_update"]),
+            "omnik_attributes": list(["inverter", "plant_id", "last_update"]),
             "omnik_dsmr": list(
                 ["inverter", "plant_id", "EQUIPMENT_IDENTIFIER", "last_update"]
             ),
@@ -196,28 +199,39 @@ class DataLogger(object):
         }
         self.config.attributes["model"] = {
             "omnik": "Omniksol",
+            "omnik_attributes": "Omniksol",
             "omnik_dsmr": "Omnik data logger",
             "dsmr": "DSMR electicity meter",
             "dsmr_gas": "DSMR gas meter",
         }
         self.config.attributes["mf"] = {
             "omnik": "Omnik",
+            "omnik_attributes": "Omnik",
             "omnik_dsmr": "JBsoft",
             "dsmr": "Netbeheer Nederland",
             "dsmr_gas": "Netbeheer Nederland",
         }
         self.config.attributes["identifier"] = {
             "omnik": "plant_id",
+            "omnik_attributes": "plant_id",
             "omnik_dsmr": "plant_id",
             "dsmr": "EQUIPMENT_IDENTIFIER",
             "dsmr_gas": "EQUIPMENT_IDENTIFIER_GAS",
         }
         self.config.attributes["devicename"] = {
             "omnik": "Inverter",
+            "omnik_attributes": "Inverter",
             "omnik_dsmr": "Omnik_data_logger",
             "dsmr": "DSMR_electicity_meter",
             "dsmr_gas": "DSMR_gasmeter",
         }
+        self.config.attributes["device_identifier"] = {
+            "omnik": "omnik",
+            "omnik_attributes": "omnik",
+            "omnik_dsmr": "omnik_dsmr",
+            "dsmr": "dsmr",
+            "dsmr_gas": "dsmr_gas",
+        }
         return asset_classes
 
     def _init_attribute_set(self, attribute, asset_class, type="string"):
@@ -332,10 +346,17 @@ class DataLogger(object):
             Plugin.hass_api = self.hass_api
 
             for plugin in self.plugins:
-                spec = importlib.util.find_spec(plugin)
-                module = importlib.util.module_from_spec(spec)
-                spec.loader.exec_module(module)
-                # importlib.import_module(plugin)
+                try:
+                    spec = importlib.util.find_spec(plugin)
+                    module = importlib.util.module_from_spec(spec)
+                    spec.loader.exec_module(module)
+                except AttributeError:
+                    hybridlogger.ha_log(
+                        self.logger,
+                        self.hass_api,
+                        "ERROR",
+                        f"Output plugin {plugin} cannot be initialized!",
+                    )
 
     def _terminate_output_plugins(self):
         while Plugin.plugins:
@@ -376,7 +397,7 @@ class DataLogger(object):
             self.dsmr_access.release()
             tries -= 1
             if not complete:
-                time.sleep(1)
+                sleep(1)
             else:
                 break
         if not tries:
@@ -420,7 +441,7 @@ class DataLogger(object):
                 "1000"
             )
             data["power_direct_use"] = Decimal("0")
-        data["last_update_calc"] = time.time()
+        data["last_update_calc"] = time()
 
     def dsmr_callback(self, terminal, dsmr_message):
         # print(f"{dsmr_message['gas_consumption_totall']} =
@@ -471,10 +492,12 @@ class DataLogger(object):
 
     def _validate_user_login(self):
         self.omnik_api_level = 0
+        returnvalue = None
         try:
-            self.client.initialize()
+            returnvalue = self.client.initialize()
             # Logged on
             self.omnik_api_level = 1
+            return returnvalue
         except RequestException as errc:
             hybridlogger.ha_log(
                 self.logger,
@@ -488,8 +511,7 @@ class DataLogger(object):
     def _logon(self):
         # Log on to the omnik portal to enable fetching plant's
         if self.omnik_api_level == 0:
-            self._validate_user_login()
-            if self.omnik_api_level == 0:
+            if not self._validate_user_login() or self.omnik_api_level == 0:
                 return False
         return True
 
@@ -499,8 +521,19 @@ class DataLogger(object):
             try:
                 plants = self.client.getPlants()
                 for pid in plants:
+                    lastupdate = (
+                        datetime.fromtimestamp(pid["last_update"]).astimezone(
+                            timezone.utc
+                        )
+                        if pid.get("last_update")
+                        else self.get_last_update(
+                            str(pid["plant_id"]),
+                            default=0.0,
+                        )
+                    )
                     self.plant_update[str(pid["plant_id"])] = Plant(
-                        pid["plant_id"], self.last_update_time.astimezone(timezone.utc)
+                        pid["plant_id"],
+                        lastupdate,
                     )
                 self.omnik_api_level = 2
             except requests.exceptions.RequestException as err:
@@ -561,9 +594,11 @@ class DataLogger(object):
                 newreporttime = datetime.fromtimestamp(data["last_update"]).astimezone(
                     timezone.utc
                 )
-                # Only proces updates that occured after we started or start a single measurement (TODO)
+                # Only proces updates that occured after we started or start a single measurement
+                # check for cached last update
                 if (
                     newreporttime > self.plant_update[plant].last_update_time
+                    or data["last_update"] > self.get_last_update(plant)
                     or not self.every
                     or self.sundown
                 ):
@@ -582,14 +617,13 @@ class DataLogger(object):
                     ].last_update_time = newreporttime.astimezone(timezone.utc)
                     data["plant_id"] = plant
                     return data
-                else:
-                    hybridlogger.ha_log(
-                        self.logger,
-                        self.hass_api,
-                        "INFO",
-                        f"No recent report update to process. Last report at UTC {newreporttime}",
-                    )
-                    return None
+                hybridlogger.ha_log(
+                    self.logger,
+                    self.hass_api,
+                    "INFO",
+                    f"No recent report update to process aggregated data. Last report at UTC {newreporttime}",
+                )
+                return None
 
         except requests.exceptions.RequestException as err:
             hybridlogger.ha_log(
@@ -622,7 +656,9 @@ class DataLogger(object):
         self._validate_field(
             data,
             "inverter",
-            self.config.get(f"plant.{plant}", "inverter_sn", "n/a"),
+            self.config.get(
+                f"plant.{plant}", "inverter_sn", data.get("inverter") or "n/a"
+            ),
         )
         if plant == "0":
             data["plant_id"] = "0"
@@ -633,7 +669,11 @@ class DataLogger(object):
         data = self._validate_client_data(plant, data)
         # Process for each plugin, but only when valid
         for plugin in Plugin.plugins:
-            if not plugin.process_aggregates or "sys_id" in data:
+            if (
+                plugin.process_output
+                or not plugin.process_aggregates
+                or "sys_id" in data
+            ):
                 hybridlogger.ha_log(
                     self.logger,
                     self.hass_api,
@@ -665,6 +705,9 @@ class DataLogger(object):
                 "current_power",
                 "today_energy",
                 "total_energy",
+                "current_ac1",
+                "current_ac2",
+                "current_ac3",
                 "voltage_ac1",
                 "voltage_ac2",
                 "voltage_ac3",
@@ -672,6 +715,8 @@ class DataLogger(object):
                 "inverter_temperature",
             ]:
                 self._init_aggregated_data_field(aggregated_data, data, field)
+            if data.get("cached"):
+                aggregated_data["cached"] = True
             if self.dsmr:
                 for field in [
                     # Attributes Electricity for pvoutput
@@ -760,25 +805,28 @@ class DataLogger(object):
         else:
             # Get sys_id from pvoutput section, cannot aggregate without sys_id
             sys_id = global_sys_id
-            if sys_id:
-                # Aggerate data (initialize dict and set sys_id)
-                self._init_aggregated_data(aggregated_data, data, sys_id)
-                # Timestamp
-                self._adapt_max_value(aggregated_data, data, "last_update")
-                # Add energy
-                self._adapt_add_value(aggregated_data, data, "today_energy")
-                self._adapt_add_value(aggregated_data, data, "total_energy")
-                # Add power
-                self._adapt_add_value(aggregated_data, data, "current_power")
-                # Max voltage
-                self._adapt_max_value(aggregated_data, data, "voltage_ac_max")
-                self._adapt_max_value(aggregated_data, data, "voltage_ac1")
-                self._adapt_max_value(aggregated_data, data, "voltage_ac2")
-                self._adapt_max_value(aggregated_data, data, "voltage_ac3")
-                self._adapt_max_value(aggregated_data, data, "net_voltage_max")
-                # Max inverter temperature
-                self._adapt_max_value(aggregated_data, data, "inverter_temperature")
-            if sys_id and self.dsmr:
+            # Aggerate data (initialize dict and set sys_id)
+            self._init_aggregated_data(aggregated_data, data, sys_id)
+            # Timestamp
+            self._adapt_max_value(aggregated_data, data, "last_update")
+            # Add energy
+            self._adapt_add_value(aggregated_data, data, "today_energy")
+            self._adapt_add_value(aggregated_data, data, "total_energy")
+            # Add power
+            self._adapt_add_value(aggregated_data, data, "current_power")
+            # Max voltage
+            self._adapt_max_value(aggregated_data, data, "voltage_ac_max")
+            self._adapt_max_value(aggregated_data, data, "voltage_ac1")
+            self._adapt_max_value(aggregated_data, data, "voltage_ac2")
+            self._adapt_max_value(aggregated_data, data, "voltage_ac3")
+            self._adapt_max_value(aggregated_data, data, "net_voltage_max")
+            # Max current
+            self._adapt_max_value(aggregated_data, data, "current_ac1")
+            self._adapt_max_value(aggregated_data, data, "current_ac2")
+            self._adapt_max_value(aggregated_data, data, "current_ac3")
+            # Max inverter temperature
+            self._adapt_max_value(aggregated_data, data, "inverter_temperature")
+            if self.dsmr:
                 self._adapt_add_value(aggregated_data, data, "power_consumption")
                 self._adapt_add_value(aggregated_data, data, "energy_used_net")
                 self._adapt_add_value(aggregated_data, data, "energy_used")
@@ -947,12 +995,12 @@ class DataLogger(object):
                 f"Cache file '{self.persistant_cache_file}' can not be written! Error: {e.args}",
             )
 
-    def get_last_update(self, plant, default=time.time()):
+    def get_last_update(self, plant, default=time()):
         last_update_key = f"{plant}.last_update"
         cache = self.cache.get(last_update_key)
         if cache:
             return datetime.timestamp(datetime.strptime(cache, "%Y-%m-%dT%H:%M:%S"))
-        return default if default else time.time().replace(microsecond=0)
+        return default
 
     def total_energy(
         self,
@@ -1078,7 +1126,7 @@ class DataLogger(object):
                     )
                     self._aggregate_data(aggegated_data, cached_data)
                     cached_last_update = self.get_last_update(plant, 0.0)
-                    if  cached_last_update > last_solar_update:
+                    if cached_last_update > last_solar_update:
                         last_solar_update = cached_last_update
             elif self.total_energy(plant_id):
                 cached_data = {}
@@ -1090,7 +1138,7 @@ class DataLogger(object):
                 )
                 self._aggregate_data(aggegated_data, cached_data)
                 cached_last_update = self.get_last_update(plant_id, 0.0)
-                if  cached_last_update > last_solar_update:
+                if cached_last_update > last_solar_update:
                     last_solar_update = cached_last_update
 
             if aggegated_data:
@@ -1135,7 +1183,9 @@ class DataLogger(object):
                 )
                 # use last solar update time stamp for real time data output (not a dsmr_time stamp)
                 data.update(aggegated_data)
-                data["last_update"] = last_solar_update if last_solar_update else dsmr_timestamp
+                data["last_update"] = (
+                    last_solar_update if last_solar_update else dsmr_timestamp
+                )
         # TODO process net update for other clients
         self._output_update(plant_id, data)
 
@@ -1179,6 +1229,7 @@ class DataLogger(object):
                     # Use cached data for aggregation with DSMR
                     data = {}
                     try:
+                        data["cached"] = True
                         data["plant_id"] = plant
                         data["last_update"] = self.get_last_update(plant)
                         data["total_energy"] = self.total_energy(plant)
